<?php
/**
 * PercorreHolerite.
 *
 * @package Logic
 *
 * @author  thalesvalias - 27/09/2012
 */
class PercorreHolerite{

    private $_parametros;
    private $_formulario;

    private $_retrocesso;

    private $_nrOrg;
    private $_nrOrgPadrao;
    private $_nrEstruturaTrab;
    private $_mesCompetencia;

    private $_dsInicio;
    private $_dsFim;
    private $_dsOrdem;
    private $_nrTpHierarquiaOrg;
    private $_idGeraMeioMagnetico;
    private $_idProcessaVinculo;
    private $_nrEstruturaResp;
    private $_filePath;
    private $_tpInscResp;
    private $_nrEvento;
    private $_nrTipoMovimento;
    private $_cdBanco;
    private $_nrGrupoHolerite;
    private $_nrTipoModalidadeCalculo;
    private $_nrOcorrenciaCalculo;

    private $_calculoFolha;
    private $_nrCalculoFolha;
    private $_holeriteMagnetico;
    private $_tipoHierarquia;
    private $_hierarquiaOrg;
    private $_vinculom;
    private $_pessoa;

    private $_estruturacao;

    private $_nomeArquivo;
    private $_holerite;

    private $_msgSucessoPersisteMagnetico;
    private $_msgSucessoGeraMagnetico;
    private $_contador;

    const PREFIXO_NOME_ARQUIVO_CNAB = 'cnab';
    const EXTENSAO_ARQUIVO = '.txt';


    /**
     * Construtor.
     *
     * @param string     $tpProcessamento Tipo de processamento (MENSAL).
     * @param integer    $nrFormulario    Numero do formulario.
     * @param Parametros $parametro       Instancia de Parametros.
     *
     * @author thalesvalias - 27/09/2012
     */
    public function __construct($tpProcessamento, $nrFormulario, Parametros $parametro){

        $this->_parametros = $parametro;
        $this->_nrOrg = $this->_parametros->getNrOrgTrabalho();
        $this->_nrOrgPadrao = $this->_parametros->getNrOrgPadrao();
        $this->_nrEstruturaTrab = $this->_parametros->getNrEstrutTrab();
        $this->_mesCompetencia = new TkDateTime($this->_parametros->getMesCompetencia());
        $this->_nrTipoModalidadeCalculo = $this->_parametros->getTipoModalidadeCalculo();
        $this->_nrOcorrenciaCalculo = $this->_parametros->getNrOcorrenciaCalculo();

        $this->_vinculom = new GpevinculomEntity();
        $this->_tipoHierarquia = new TipohierarqorgEntity();
        $this->_hierarquiaOrg = new HierarquiaorgEntity();
        $this->_calculoFolha = new FpacalculofolhaEntity();
        $this->_holeriteMagnetico = new FpaholeritemagnetEntity();

        $this->_pessoa = new GpepessoaEntity(null, $this->_nrOrg, $this->_mesCompetencia);
        $this->_estruturacao = new Estruturacao($this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia);

        $this->_inicializaVariaveis($nrFormulario);

        $tpProcessamento = strtoupper($tpProcessamento);
        switch ($tpProcessamento){
        case Parametros::PROC_COMPETENCIA_MENSAL :
             $this->_retrocesso = false;
             break;
        case Parametros::PROC_RETROCESSO :
            $this->_retrocesso = true;
            break;
        default:
            tk_message('Tipo de processo '.$tpProcessamento.' inválido', 'warning');
        }

        $this->_holerite = new Holerite(
            $this->_nrOrg, $this->_nrOrgPadrao, $this->_mesCompetencia, $this->_holeriteMagnetico, $this->_formulario, $this->_nrCalculoFolha
        );
    }


    public function _inicializaVariaveis($nrFormulario) {

        $this->_buscaDadosFormulario($nrFormulario);

        $calculoFolha = $this->_calculoFolha->retornaCalculoFolha(
            $this->_nrOrg, $this->_nrTipoMovimento,  $this->_mesCompetencia, $this->_nrTipoModalidadeCalculo, $this->_nrOcorrenciaCalculo
        );
        $this->_nrCalculoFolha = end($calculoFolha)->getNrcalculofolha();

        $this->_msgSucessoPersisteMagnetico = null;
        $this->_msgSucessoGeraMagnetico = null;
    }

    /**
     * Percorre os vinculos para geracao dos registros.
     *
     * @throws Exception Propaga excecao.
     *
     * @return void
     *
     * @author thalesvalias - 27/09/2012
     */
    public function percorre(){
        if ($this->_retrocesso === false) {
            try{
                $this->_geraHolerite();
                if ($this->_msgSucessoPersisteMagnetico !== null) {
                    tk_warning($this->_msgSucessoPersisteMagnetico);
                }
                if ($this->_msgSucessoGeraMagnetico !== null) {
                    tk_warning($this->_msgSucessoGeraMagnetico);
                }
            }catch (Exception $e) {
                throw new Exception($e);
            }
        } else {
            try {
                $this->_holerite->retroceder();
                tk_message('RETROCESSO', 'warning');
            } catch (Exception $e) {
                throw new Exception($e);
            }
        }
    }


    /**
     * Gera os registros do arquivo Holerite.
     *
     * @throws Exception Propaga Excecao.
     *
     * @return void
     *
     * @author thalesvalias - 27/09/2012
     */
    private function _geraCNAB(){

        // Percorre os vinculos gerando os registro do Holerite.
        if ($this->_idProcessaVinculo === true) {
            // Inicializa Lista do Magnetico.
            $this->_holeriteMagnetico->inicializaListaRegistros(
                $this->_mesCompetencia, RegistroHolerite::LISTA_TIPO_REGISTROS_UNICO, $this->_nrOrg, $this->_cdBanco, $this->_nrTipoMovimento
            );

            // Retorna todos os vinculos.
            $vinculos = $this->_vinculom->retornaVinculosAtivosMesCompetencia(
                $this->_nrOrg, $this->_mesCompetencia, $this->_dsInicio, $this->_dsFim, $this->_dsOrdem, false,
                $this->_nrEstruturaTrab
            );

            // Percorre os vinculos gerando o Holerite Eletronico.
            foreach ($vinculos as $vinculo) {
                try {
                    $this->_holerite->preparaHolerite($vinculo);
                } catch(Exception $e) {
                    throw new Exception('Inconsistência na geração do registro de Holerite Eletronico.'.$e);
                }
            }

            // So persiste se a lista nao estiver vazia.
            $qtdRegistros = count($this->_holeriteMagnetico->getItems());
            if ($qtdRegistros > 0) {
                $persisteHolerite = $this->_holeriteMagnetico->persist();
                if ($persisteHolerite === true) {
                    $this->_msgSucessoPersisteMagnetico = "Holerite Eletronico gravado com sucesso!";
                }
            }
        }

        // Gera o magnetico.
        if ($this->_idGeraMeioMagnetico === true) {
            $this->_geraMagnetico();
        }
    }


    /**
     * Gera o magnetico: grava todos os registros na base e gera o arquivo de Holerite Eletronico.
     *
     * @return void
     *
     * @author thalesvalias - 27/09/2012
     */
    private function _geraMagnetico(){

        // Busca da base os resgistros daquela competencia, banco e tipo de movimento ordenados por inscricao e tipo de registro.
        $resultado = $this->_holeriteMagnetico->retornaRegistros($this->_mesCompetencia, $this->_nrOrg, $this->_cdBanco, $this->_nrTipoMovimento);

        if (count($resultado) > 0) {

            // Define o nome do arquivo.
            $this->_constroiNomeArquivo();

            // Monta o diretorio completo, incluindo o nome do arquivo a ser gerado.
            $caminhoArquivo = $this->_filePath."\\".$this->_nomeArquivo;

            // Criar o arquivo.
            $arquivo = new TkFile($caminhoArquivo, true);

            $this->_contador = 1;
            // Loop no resultado. Armazena os registros, modifica as linhas necessarias e adiciona quebra de linha.
            foreach ($resultado as $item) {

                // O resultado dos registros ja vem ordenado. Modifica as linhas necessarias (consolidacao e sequencia).
                $linhaRegistro = $this->_modificaLinhas($item);

//                // Se for registro 5, seta o valor total do pagamento para persistir no magnetico.
//                if ($item->getIdtiporegistro() === Registro5CNABSantander::REGISTRO_5) {
//                    $valorTotalPagamento = $this->_cnab->getValorTotalPagamento();
//                    $item->setValor($valorTotalPagamento);
//                }

                $item->persist();
                $arquivo->add($linhaRegistro);

                // Nao adiciona quebra de linha apos inclusao da ultima linha.
                if (end($resultado) !== $item) {
                    $arquivo->add(RegistroHolerite::QUEBRA_LINHA_CR_LF);
                }
            }

            $geraArquivo = $arquivo->save();

            if (empty($geraArquivo) === false) {
                $this->_msgSucessoGeraMagnetico =  "Arquivo gerado com sucesso!";
            }
        }
    }

    // @todo PAREI AQUI A REORGANIZAR O ARQUIVO.
    /**
     * Modifica a linha informada de acordo com as necessidades (squencia, consolidacao) e a retorna.
     *
     * @param FpaCnabmagnetEntity $itemCnabMagnetico instancia de FpaCnabmagnetEntity.
     *
     * @return string (linha modificada do registro)
     *
     * @author thalesvalias - 07/08/2012
     */
    private function _modificaLinhas(FpaCnabmagnetEntity $itemCnabMagnetico) {
        // Caso o registro seja do tipo 3, modifica sua sequencia.
        $linhaRegistro = $itemCnabMagnetico->getDslinharegistro();
        $tipoRegistro = $itemCnabMagnetico->getIdtiporegistro();

        if ($tipoRegistro === RegistroCNAB::REGISTRO_3) {
            $linhaRegistro = $this->_cnab->modificaSequencia($linhaRegistro, $this->_contador);
            $itemCnabMagnetico->setDslinharegistro($linhaRegistro);
            $this->_contador++;
        } else {
            $linhaRegistro = $this->_cnab->modificaLinhasConsolidacao($tipoRegistro, $linhaRegistro);
            $itemCnabMagnetico->setDslinharegistro($linhaRegistro);
        }

        return $linhaRegistro;
    }


    /**
     * Constroi o nome do arquivo magnetico do cnab.
     *
     * @return void
     *
     * @author thalesvalias - 10/08/2012
     */
    private function _constroiNomeArquivo() {
        $anoCompetencia = $this->_mesCompetencia->toString(TkDateTime::YEAR);
        $mesCompetencia = $this->_mesCompetencia->toString(TkDateTime::MONTH);

        // Verifica se o arquivo a ser gerado sera de acerto ou nao. O tratamento do nome varia de acordo com o tipo de atualizacao.
        $this->_nomeArquivo = self::PREFIXO_NOME_ARQUIVO_CNAB.$mesCompetencia.$anoCompetencia.FPARegistro::CARACTER_UNDERLINE
            .$this->_cdBanco.FPARegistro::CARACTER_UNDERLINE.$this->_nrTipoMovimento.self::EXTENSAO_ARQUIVO;
    }


    /**
     * Busca dados do formulario.
     *
     * @param integer $nrFormulario Numero do formulario.
     *
     * @return void
     *
     * @author thalesvalias - 26/07/2012
     */
    private function _buscaDadosFormulario($nrFormulario){
        $formulario = new FpaFormcnabEntity();
        $this->_formulario = $formulario->retornaDadosFormularioCNAB($this->_nrOrg, $nrFormulario);
        if (is_object($this->_formulario) === true) {
            $this->_dsInicio = $this->_formulario->getDsinicio();
            $this->_dsFim = $this->_formulario->getDsfim();
            $this->_dsOrdem = $this->_formulario->getDsordem();
            $this->_nrTpHierarquiaOrg = $this->_formulario->getNrhierarqorg();
            $this->_idProcessaVinculo = $this->_formulario->getIdprocvinculo();
            $this->_idGeraMeioMagnetico = $this->_formulario->getIdgerameiomag();
            $this->_filePath = $this->_formulario->getDscaminhoarquivo();
            $this->_nrEstruturaResp = $this->_formulario->getNrestrutrespons();
            $this->_tpInscResp = $this->_formulario->getIdtpinscrespons();
            $this->_nrEvento = $this->_formulario->getNreventom();
            $this->_nrTipoMovimento = $this->_formulario->getNrtipomoviment();
            $this->_cdBanco = $this->_formulario->getCdbanco();
            $this->_nrGrupoCnab = $this->_formulario->getNrgrupocnab();
        }
    }


}