DROP TYPE QUERY_ITEM_DFS48000_TABLE
/

DROP TYPE QUERY_ITEM_DFS48000_TYPE
/

CREATE TYPE QUERY_ITEM_DFS48000_TYPE AS
OBJECT(IDCHECKPRAF       VARCHAR2(1),
       CDFILIAL          VARCHAR2(4),
       CDARVPROD         VARCHAR2(20),
       NMPRODUTO         VARCHAR2(50),
       CDPRODUTO         VARCHAR2(10),
       SGUNIDADE         VARCHAR2(10),
       CDMARCA           VARCHAR2(5),
       CDMARCAOL         VARCHAR2(5),
       CDMARCAAF         VARCHAR2(5),
       NMMARCA           VARCHAR2(20),
       NRAUTOFORN        VARCHAR2(10),
       CDFILLANC         VARCHAR2(4),
       NRLANCTONF        VARCHAR2(10),
       IDBAIXITAFS       VARCHAR2(1),
       CDFILDEST         VARCHAR2(4),
       IDUTILITEM        VARCHAR2(1),
       CDALMOXARIFE      VARCHAR2(6),
       CDLOCALESTOQ      VARCHAR2(6),
       NRLOTEESTQ        VARCHAR2(20),
       NRSUBLOTE         VARCHAR2(4),
       IDUTQTESTRANG     VARCHAR2(1),
       CDCLIENTEEXT      VARCHAR2(21),
       DTPROGEMBARQ      DATE,
       DTPROGENTAF       DATE,
       DTPROGENPEOL      DATE,
       QTPROGENTAF       FLOAT,
       QTSAIDOPLOG       FLOAT,
       VRPREUNIAF        FLOAT,
       QTNFRELAFSAI      FLOAT,
       QTATENDPEDOL      FLOAT,
       VRPBRUTOPEDOL     FLOAT,
       VRPLIQUIPEDOL     FLOAT,
       QTATENDESTRANG    FLOAT);
/

CREATE TYPE QUERY_ITEM_DFS48000_TABLE AS TABLE OF QUERY_ITEM_DFS48000_TYPE
/

CREATE OR REPLACE FUNCTION QUERY_ITEM_DFS48000 (P_FILOPELOG        IN VARCHAR2,   /*CDFILIOPELOG*/
                                                P_FILDEST          IN VARCHAR2,   /*CDFILDEST*/
                                                P_CDFILLANC        IN VARCHAR2,   /*CDFILLANC*/
                                                P_NRAUTOFORN       IN VARCHAR2,   /*NRAUTOFORN*/
                                                P_SUBGRUPO         IN VARCHAR2,   /* "T" OU  SUBGRUPO*/
                                                P_DATAENT          IN VARCHAR2,   /*"0 data de Entrega" OU "1 data de Embarque"*/
                                                P_DTENTREGA        IN DATE,       /*Data de entrega*/
                                                P_DTPROC           IN DATE,       /*Data de processamento*/
                                                P_PEDOLEXTR        IN VARCHAR2,   /*"S" ou "N" ou "T"*/
                                                P_CDLOTENVIOL      IN VARCHAR2,   /*Lista Lote, No considerada = 'N' e sem lote = 'T'*/
                                                P_IDBAIXAOLSAI     IN VARCHAR2,   /*"T" ou NULL*/
                                                P_IDUTILCONSSOLIOL IN VARCHAR2    /*"S" ou "N"*/
                                                ) RETURN QUERY_ITEM_DFS48000_TABLE PIPELINED
IS
   OUT_RECORD QUERY_ITEM_DFS48000_TYPE := QUERY_ITEM_DFS48000_TYPE (NULL, NULL, NULL, NULL, NULL,
                                                                    NULL, NULL, NULL, NULL, NULL,
                                                                    NULL, NULL, NULL, NULL, NULL,
                                                                    NULL, NULL, NULL, NULL, NULL,
                                                                    NULL, NULL, NULL, NULL, NULL,
                                                                    0, 0, 0, 0, 0, 0, 0, 0);
   TYPE CURTYPE      IS REF CURSOR;
   C_ITEM            CURTYPE;
   V_CDFILIAL        VARCHAR2(4);
   V_CDARVPROD       VARCHAR2(20);
   V_NMPRODUTO       VARCHAR2(50);
   V_CDPRODUTO       VARCHAR2(10);
   V_SGUNIDADE       VARCHAR2(10);
   V_CDMARCA         VARCHAR2(5);
   V_CDMARCAOL       VARCHAR2(5);
   V_CDMARCAAF       VARCHAR2(5);
   V_NMMARCA         VARCHAR2(20);
   V_NRAUTOFORN      VARCHAR2(10);
   V_CDFILLANC       VARCHAR2(4);
   V_NRLANCTONF      VARCHAR2(10);
   V_IDBAIXITAFS     VARCHAR2(1);
   V_CDFILDEST       VARCHAR2(4);
   V_IDUTILITEM      VARCHAR2(1);
   V_CDALMOXARIFE    VARCHAR2(6);
   V_CDLOCALESTOQ    VARCHAR2(6);
   V_NRLOTEESTQ      VARCHAR2(20);
   V_NRSUBLOTE       VARCHAR2(4);
   V_IDUTQTESTRANG   VARCHAR2(1);
   V_CDCLIENTEEXT    VARCHAR2(21);
   V_CDPRECOBASE     VARCHAR2(2);
   V_CDFCUSNFROMA    VARCHAR2(4);
   V_IDTCUSNFROMA    VARCHAR2(2);
   V_DTPROGEMBARQ    DATE;
   V_DTPROGENTAF     DATE;
   V_DTPROGENPEOL    DATE;
   V_QTPROGENTAF     FLOAT;
   V_QTSAIDOPLOG     FLOAT;
   V_VRPREUNIAF      FLOAT;
   V_QTNFRELAFSAI    FLOAT;
   V_QTATENDPEDOL    FLOAT;
   V_VRPBRUTOPEDOL   FLOAT;
   V_VRPLIQUIPEDOL   FLOAT;
   V_QTATENDESTRANG  FLOAT;
   V_TIPOCUSTO       FLOAT;
BEGIN
   IF P_IDUTILCONSSOLIOL = 'S' THEN  /*CONSULTA PEDIDO OL*/
      SELECT MAX(NVL(FP.CDPRECOBASE, NVL(FI.CDPRECOBASE, T.CDPRECOBASE)))
        INTO V_CDPRECOBASE
        FROM TIPOOPEROPL TL, TIPOOPERAC T, FILIAL FI, PARAMFILIAL PF, FILIAL FP,
             (SELECT P.CDFILDEST
                FROM PEDIDOEXOL P
               WHERE CASE NVL(P.CDCLIENTEEXT, 'O')
                        WHEN 'O'
                        THEN P.CDFILDEST
                        ELSE P.CDCLIENTEEXT
                     END             = P_FILDEST
                 AND P.CDFILLANC     = P_CDFILLANC
                 AND P.NRPEDEXOL     = P_NRAUTOFORN) PD
       WHERE TL.CDFILIOPELOG   = P_FILOPELOG
         AND TL.CDFILDEST      = PD.CDFILDEST
         AND TL.CDTIPOOPERSAID = T.CDTIPOOPER
         AND TL.IDTIPOOPERSAID = T.IDENTRSAIDOP
         AND TL.CDFILDEST      = FI.CDFILIAL
         AND TL.CDFILIOPELOG   = PF.CDFILIAL
         AND PF.CDFCUSNFROMA   = FP.CDFILIAL(+);

      SELECT MAX(CDFCUSNFROMA), MAX(NVL(IDTCUSNFROMA, '')), MAX(TO_NUMBER(NVL(CDTIPCUSTEST,'03')))
             INTO V_CDFCUSNFROMA, V_IDTCUSNFROMA, V_TIPOCUSTO
        FROM PARAMFILIAL
       WHERE CDFILIAL = P_FILOPELOG;
      IF V_CDFCUSNFROMA IS NOT NULL THEN
         SELECT MAX(CDFCUSNFROMA), MAX(NVL(IDTCUSNFROMA, '')), MAX(TO_NUMBER(NVL(CDTIPCUSTEST,'03')))
                INTO V_CDFCUSNFROMA, V_IDTCUSNFROMA, V_TIPOCUSTO
           FROM PARAMFILIAL
          WHERE CDFILIAL = V_CDFCUSNFROMA;
      ELSE
         SELECT MAX(CDFCUSNFROMA), MAX(NVL(IDTCUSNFROMA, '')), MAX(TO_NUMBER(NVL(CDTIPCUSTEST,'03')))
                INTO V_CDFCUSNFROMA, V_IDTCUSNFROMA, V_TIPOCUSTO
           FROM PARAMFILIAL
          WHERE CDFILIAL = P_FILOPELOG;
      END IF;
      IF  V_IDTCUSNFROMA <> '' THEN
         V_TIPOCUSTO := TO_NUMBER(V_IDTCUSNFROMA);
      END IF;
      OPEN C_ITEM FOR
         SELECT P.CDFILDEST AS CDFILIAL, B.CDARVPROD,
                B.NMPRODUTO, I.CDPRODUTO, B.SGUNIDADE, I.CDMARCA, I.CDMARCA AS CDMARCAOL,
                I.CDMARCA AS CDMARCAAF, M.NMMARCA, I.QTPROGENPEOL AS QTPROGENTAF,
                DECODE(NVL(I.QTEFETENPEOL,0), 0, I.QTPROGENPEOL, I.QTEFETENPEOL) AS QTSAIDOPLOG,
                CASE (NVL(APURA_PRECOBASE (V_CDPRECOBASE, R.CDPRODARVOL, P_DTENTREGA), 0))
                   WHEN 0
                   THEN (CASE (NVL(CUSTO_PRODUTO_LCEST(NVL(PF.CDFCUSNFROMA,P_FILOPELOG), E.CDPRODESTO, V_TIPOCUSTO, (TO_DATE(P_DTPROC) - 1), SYSDATE,
                                        NVL(ETQ.CDALMOXARIFE, ' '), NVL(ETQ.CDLOCALESTOQ, ' '), NVL(ETQ.NRLOTEESTQ, ' '),
                                        NVL(ETQ.NRSUBLOTE, ' ')), 0) * (CASE E.CDPRODESTO WHEN E.CDPRODUTO THEN 1 ELSE B.VRFATOCONV END))
                            WHEN 0
                            THEN (NVL(CUSTO_PRODUTO(NVL(PF.CDFCUSNFROMA,P_FILOPELOG), E.CDPRODESTO, V_TIPOCUSTO, P_DTPROC, SYSDATE), 0) * (CASE E.CDPRODESTO WHEN E.CDPRODUTO THEN 1 ELSE B.VRFATOCONV END))
                            ELSE (NVL(CUSTO_PRODUTO_LCEST(NVL(PF.CDFCUSNFROMA,P_FILOPELOG), E.CDPRODESTO, V_TIPOCUSTO, (TO_DATE(P_DTPROC) - 1), SYSDATE,
                                        NVL(ETQ.CDALMOXARIFE, ' '), NVL(ETQ.CDLOCALESTOQ, ' '), NVL(ETQ.NRLOTEESTQ, ' '),
                                        NVL(ETQ.NRSUBLOTE, ' ')), 0) * (CASE E.CDPRODESTO WHEN E.CDPRODUTO THEN 1 ELSE B.VRFATOCONV END)) END
                        )
                   ELSE (NVL(APURA_PRECOBASE (V_CDPRECOBASE, R.CDPRODARVOL, P_DTENTREGA), 0)) END AS VRPREUNIAF,
                I.NRPEDEXOL AS NRAUTOFORN, I.CDFILLANC, DECODE(P_DATAENT, '0', I.DTPROGENPEOL, I.DTPROGEMBARQ) DTPROGENTAF,
                A.NRLANCTONF, A.QTNFRELAFSAI, I.IDBAIXAOLSAI AS IDBAIXITAFS, I.CDFILDEST,
                CASE  ''/*P_TQTEFAFSAIDOL*/
                   WHEN 'T'
                   THEN (CASE NVL(ETQ.IDUTQTESTRANG, 'S')
                       WHEN 'S'
                       THEN NVL(ETQ.VRPESOETIQ, NVL(I.QTATENDPEDOL, 0)) - NVL(I.QTATENDESTRANG, 0)
                       ELSE NVL(ETQ.VRPESOETIQ, NVL(I.QTATENDPEDOL, 0))
                       END )
                   ELSE NVL(ETQ.VRPESOETIQ, NVL(I.QTATENDPEDOL, 0))
                END  QTATENDPEDOL,
                I.VRPBRUTOPEDOL, I.VRPLIQUIPEDOL, I.DTPROGEMBARQ,
                '2' AS IDUTILITEM, I.DTPROGENPEOL,
                CASE NVL(ETQ.IDUTQTESTRANG, 'S')
                   WHEN 'S'
                   THEN NVL(I.QTATENDESTRANG, 0)
                   ELSE 0
                   END  QTATENDESTRANG,
                ETQ.NRLOTEESTQ, ETQ.NRSUBLOTE, ETQ.CDLOCALESTOQ, ETQ.CDALMOXARIFE,
                NVL(ETQ.IDUTQTESTRANG, 'N') IDUTQTESTRANG, P.CDCLIENTEEXT
           FROM PEDIDOEXOL P, ITEMPEDEXOL I, RELACPRODOL R, MARCA M,
                FILIAL FI, PARAMFILIAL PF, FILIAL FP, PRODUTO B, PRODUTO E,
                (SELECT N.CDFILDEST, N.CDFILLANC, N.NRPEDEXOL, N.CDMARCA, N.CDPRODUTO, N.DTPROGENPEOL,
                        MAX(N.NRLANCTONF) AS NRLANCTONF, SUM(N.QTNFRELPEXOL) AS QTNFRELAFSAI
                   FROM PEDIDOEXOL P, NFRELACPEXOL N, ITEMPEDEXOL IT
                  WHERE CASE NVL(P.CDCLIENTEEXT, 'O')
                           WHEN 'O'
                           THEN P.CDFILDEST
                           ELSE P.CDCLIENTEEXT
                        END             = P_FILDEST
                    AND (P.CDFILLANC    = P_CDFILLANC)
                    AND (P.NRPEDEXOL    = P_NRAUTOFORN)
                    AND (P.CDFILDEST    = N.CDFILDEST)
                    AND (P.CDFILLANC    = N.CDFILLANC)
                    AND (P.NRPEDEXOL    = IT.NRPEDEXOL)
                    AND (DECODE(P_DATAENT, '0', IT.DTPROGENPEOL, IT.DTPROGEMBARQ) = P_DTENTREGA)
                    AND (N.CDFILDEST    = IT.CDFILDEST)
                    AND (N.CDFILLANC    = IT.CDFILLANC)
                    AND (N.NRPEDEXOL    = IT.NRPEDEXOL)
                    AND (N.CDMARCA      = IT.CDMARCA)
                    AND (N.CDPRODUTO    = IT.CDPRODUTO)
                    AND (N.DTPROGENPEOL = IT.DTPROGENPEOL)
                    AND (N.CDFILIAL    <> P_FILOPELOG)
                  GROUP BY N.CDFILDEST, N.CDFILLANC, N.NRPEDEXOL, N.CDMARCA, N.CDPRODUTO, N.DTPROGENPEOL) A,
                (SELECT E.CDFILDEST, E.CDFILLANC, E.NRPEDEXOL,
                        SUM(E.VRPESOETIQ) AS VRPESOETIQ, E.DTPROGENPEOL, IP.NRLOTEESTQ,
                        IP.NRSUBLOTE, IP.CDLOCALESTOQ, IP.CDALMOXARIFE, RL.CDMARCA,
                        RL.CDPRARVORIG, RL.CDPRODARVOL, NVL(E.IDUTQTESTRANG, 'N') IDUTQTESTRANG
                   FROM PEDIDOEXOL P, ETIQUETAPRODOL E, ITEMPRODUTO IP, RELACPRODOL RL, ITEMPEDEXOL I
                  WHERE CASE NVL(P.CDCLIENTEEXT, 'O')
                           WHEN 'O'
                           THEN P.CDFILDEST
                           ELSE P.CDCLIENTEEXT
                        END             = P_FILDEST
                    AND (P.CDFILLANC    = P_CDFILLANC)
                    AND (P.NRPEDEXOL    = P_NRAUTOFORN)
                    AND (P.CDFILDEST    = I.CDFILDEST)
                    AND (P.CDFILLANC    = I.CDFILLANC)
                    AND (P.NRPEDEXOL    = I.NRPEDEXOL)
                    AND (E.DTPROGENPEOL = P_DTENTREGA)
                    AND (E.CDFILIAL     = IP.CDFILIAL)
                    AND (E.NRLANCTONF   = IP.NRLANCTONF)
                    AND (E.NRSEQITPROD  = IP.NRSEQITPROD)
                    AND (E.CDPRODUTO    = RL.CDPRODARVOL)
                    AND (I.CDMARCA      = RL.CDMARCA)
                    AND (I.CDPRODUTO    = RL.CDPRARVORIG)
                    AND (E.CDFILDEST    = I.CDFILDEST)
                    AND (E.CDFILLANC    = I.CDFILLANC)
                    AND (E.NRPEDEXOL    = I.NRPEDEXOL)
                    AND (E.DTPROGENPEOL = I.DTPROGENPEOL)
                  GROUP BY E.CDPRODUTO, E.CDFILDEST, E.CDFILLANC, E.NRPEDEXOL,
                        E.DTPROGENPEOL, IP.NRLOTEESTQ, IP.NRSUBLOTE, IP.CDLOCALESTOQ, IP.CDALMOXARIFE,
                        RL.CDMARCA, RL.CDPRARVORIG, RL.CDPRODARVOL, NVL(E.IDUTQTESTRANG, 'N')) ETQ
           WHERE CASE NVL(P.CDCLIENTEEXT, 'O')
                     WHEN 'O'
                     THEN P.CDFILDEST
                     ELSE P.CDCLIENTEEXT
                 END             = P_FILDEST
             AND (P.CDFILLANC    = P_CDFILLANC)
             AND ((P.NRPEDEXOL   = P_NRAUTOFORN) OR ( 'T' = P_NRAUTOFORN))
             AND (P.CDFILIOPELOG = P_FILOPELOG)
             AND (P.CDFILDEST    = I.CDFILDEST)
             AND (P.CDFILLANC    = I.CDFILLANC)
             AND (P.NRPEDEXOL    = I.NRPEDEXOL)
             AND (I.CDMARCA      = R.CDMARCA)
             AND (I.IDBAIXAOLSAI IS NULL OR P_IDBAIXAOLSAI = 'T')
             AND (P.IDPEDEXOLEXTR = P_PEDOLEXTR OR P_PEDOLEXTR   = 'T')
             AND ((INSTR(P_CDLOTENVIOL, I.CDLOTENVITOL) > 0) OR (NVL(I.CDLOTENVITOL, P_CDLOTENVIOL) = 'T') OR (P_CDLOTENVIOL = 'N'))
             AND (NVL(I.IDITEMAJUSTE, 'N') = 'N')
             AND (DECODE(P_DATAENT, '0', I.DTPROGENPEOL, I.DTPROGEMBARQ) = P_DTENTREGA)
             AND (I.CDMARCA         = M.CDMARCA)
             AND (B.CDPRODUTO       = R.CDPRARVORIG)
             AND (E.CDPRODUTO       = R.CDPRODARVOL)
             AND (I.CDPRODUTO       = B.CDPRODUTO)
             AND (I.CDFILDEST       = A.CDFILDEST(+))
             AND (I.CDFILLANC       = A.CDFILLANC(+))
             AND (I.NRPEDEXOL       = A.NRPEDEXOL(+))
             AND (I.CDMARCA         = A.CDMARCA(+))
             AND (I.CDPRODUTO       = A.CDPRODUTO(+))
             AND (I.DTPROGENPEOL    = A.DTPROGENPEOL(+))
             AND (P.CDFILIOPELOG    = FI.CDFILIAL)
             AND (P.CDFILIOPELOG    = PF.CDFILIAL)
             AND (PF.CDFCUSNFROMA   = FP.CDFILIAL(+))
             AND (I.CDMARCA        = ETQ.CDMARCA(+))
             AND (I.CDPRODUTO      = ETQ.CDPRARVORIG(+))
             AND (I.CDFILDEST      = ETQ.CDFILDEST(+))
             AND (I.CDFILLANC      = ETQ.CDFILLANC(+))
             AND (I.NRPEDEXOL      = ETQ.NRPEDEXOL(+))
             AND (I.DTPROGENPEOL   = ETQ.DTPROGENPEOL(+))
             AND (P_SUBGRUPO =  'T' OR EXISTS (SELECT 1
                                                 FROM PRSUBGRPROD PR, PARASUPRI PA
                                                WHERE PR.CDPRODUTO  = I.CDPRODUTO
                                                  AND PR.CDGRUPPROD = PA.CDGRUPPROD
                                                  AND NVL(FI.CDFILCENTCMP, FI.CDFILIAL) = PA.CDFILIAL
                                                  AND (INSTR(P_SUBGRUPO, PR.CDSUBGRPROD) > 0)))
           ORDER BY CDFILIAL, NMPRODUTO, 6;
   ELSE /*CONSULTA AF DE FILIAL*/
      OPEN C_ITEM FOR
         SELECT F.CDFILDEST CDFILIAL, B.CDARVPROD, B.NMPRODUTO, I.CDPRODUTO, B.SGUNIDADE,
                NVL(I.CDMARCAOL, I.CDMARCA) AS CDMARCA, I.CDMARCAOL, I.CDMARCA AS CDMARCAAF, M.NMMARCA, I.QTPROGENTAF,
                DECODE(NVL(I.QTSAIDOPLOG,0), 0, I.QTPROGENTAF, I.QTSAIDOPLOG) AS QTSAIDOPLOG, I.VRPREUNIAF,
                I.NRAUTOFORN, I.CDFILLANC, I.DTPROGENTAF, A.NRLANCTONF, A.QTNFRELAFSAI, I.IDBAIXITAFS, I.CDFILDEST,
                CASE ''/*P_TQTEFAFSAIDOL*/
                   WHEN 'T'
                   THEN NVL(I.QTATENDPEDOL, 0) - NVL(I.QTATENDESTRANG, 0)
                   ELSE NVL(I.QTATENDPEDOL, 0)
                END  QTATENDPEDOL, 0 AS VRPBRUTOPEDOL, 0 AS VRPLIQUIPEDOL, SYSDATE AS DTPROGEMBARQ,
                '1' AS IDUTILITEM, SYSDATE AS DTPROGENPEOL, NVL(I.QTATENDESTRANG, 0) QTATENDESTRANG,
                '' NRLOTEESTQ, '' NRSUBLOTE, '' CDLOCALESTOQ, '' CDALMOXARIFE, '' IDUTQTESTRANG, '' CDCLIENTEEXT
           FROM ITEMAUTF I, PRODUTO B, MARCA M, AUTOFORNE F, FILIAL FI,
                (SELECT N.CDFILDEST, N.CDFILLANC, N.NRAUTOFORN, N.CDMARCA, N.CDPRODUTO, N.DTPROGENTAF,
                        MAX(N.NRLANCTONF) AS NRLANCTONF, SUM(N.QTNFRELAFSAI) AS QTNFRELAFSAI
                   FROM NFRELACAFSAI N, ITEMAUTF IT
                  WHERE N.CDFILDEST    = P_FILDEST
                    AND N.DTPROGENTAF  = P_DTENTREGA
                    AND N.CDFILLANC    = P_CDFILLANC
                    AND N.CDFILDEST    = IT.CDFILDEST
                    AND N.CDFILLANC    = IT.CDFILLANC
                    AND N.NRAUTOFORN   = IT.NRAUTOFORN
                    AND N.CDMARCA      = IT.CDMARCA
                    AND N.CDPRODUTO    = IT.CDPRODUTO
                    AND N.DTPROGENTAF  = IT.DTPROGENTAF
                    AND N.CDFILIAL    <> P_FILOPELOG
                  GROUP BY N.CDFILDEST, N.CDFILLANC, N.NRAUTOFORN, N.CDMARCA, N.CDPRODUTO, N.DTPROGENTAF) A
          WHERE F.CDFILIOPELOG = P_FILOPELOG
            AND F.CDFILDEST    = P_FILDEST
            AND F.CDFILLANC    = P_CDFILLANC
            AND F.CDFILDEST    = FI.CDFILIAL
            AND F.CDFILDEST    = I.CDFILDEST
            AND I.DTPROGENTAF  = P_DTENTREGA
            AND I.CDPRODUTO    = B.CDPRODUTO
            AND I.CDFILDEST    = F.CDFILDEST
            AND I.CDFILLANC    = F.CDFILLANC
            AND I.NRAUTOFORN   = F.NRAUTOFORN
            AND I.CDFILDEST    = A.CDFILDEST(+)
            AND I.CDFILLANC    = A.CDFILLANC(+)
            AND I.NRAUTOFORN   = A.NRAUTOFORN(+)
            AND I.CDMARCA      = A.CDMARCA(+)
            AND I.CDPRODUTO    = A.CDPRODUTO(+)
            AND I.DTPROGENTAF  = A.DTPROGENTAF(+)
            AND ((NVL(I.QTATENDPEDOL, 0) > 0) OR P_IDBAIXAOLSAI = 'T')
            AND ((I.IDBAIXITAFS IS NULL)      OR (P_IDBAIXAOLSAI = 'T'))
            AND NVL(I.CDMARCAOL, I.CDMARCA) = M.CDMARCA
            AND (P_SUBGRUPO =  'T' OR EXISTS (SELECT 1
                                                  FROM PRSUBGRPROD PR, PARASUPRI PA
                                                 WHERE PR.CDPRODUTO  = I.CDPRODUTO
                                                   AND PR.CDGRUPPROD = PA.CDGRUPPROD
                                                   AND NVL(FI.CDFILCENTCMP, FI.CDFILIAL) = PA.CDFILIAL
                                                   AND (INSTR(P_SUBGRUPO, PR.CDSUBGRPROD) > 0)))
            AND ((I.NRAUTOFORN = P_NRAUTOFORN) OR ( 'T' = P_NRAUTOFORN))
            AND NVL(I.IDTPGERARUP, 'S') <> 'T'
            AND NVL(I.IDITAFMIGRADA, 'N') = 'N'
            AND ((F.IDAFOPERLOG  = '2')  OR EXISTS (SELECT 1
                                                      FROM NFRELACAFSAI
                                                     WHERE NFRELACAFSAI.CDFILDEST  = F.CDFILDEST
                                                       AND NFRELACAFSAI.CDFILLANC  = F.CDFILLANC
                                                       AND NFRELACAFSAI.NRAUTOFORN = F.NRAUTOFORN))
             ORDER BY
                CDFILIAL, NMPRODUTO, 6;
   END IF;
   LOOP
   FETCH C_ITEM INTO V_CDFILIAL, V_CDARVPROD, V_NMPRODUTO, V_CDPRODUTO, V_SGUNIDADE, V_CDMARCA, V_CDMARCAOL,
                     V_CDMARCAAF, V_NMMARCA, V_QTPROGENTAF,V_QTSAIDOPLOG, V_VRPREUNIAF,V_NRAUTOFORN,
                     V_CDFILLANC, V_DTPROGENTAF, V_NRLANCTONF, V_QTNFRELAFSAI, V_IDBAIXITAFS, V_CDFILDEST,
                     V_QTATENDPEDOL,V_VRPBRUTOPEDOL, V_VRPLIQUIPEDOL, V_DTPROGEMBARQ, V_IDUTILITEM, V_DTPROGENPEOL,
                     V_QTATENDESTRANG, V_NRLOTEESTQ, V_NRSUBLOTE, V_CDLOCALESTOQ, V_CDALMOXARIFE,
                     V_IDUTQTESTRANG, V_CDCLIENTEEXT;
   EXIT WHEN C_ITEM%NOTFOUND;
      OUT_RECORD.IDCHECKPRAF          := 'U';
      OUT_RECORD.CDFILIAL             := V_CDFILIAL;
      OUT_RECORD.CDARVPROD            := V_CDARVPROD;
      OUT_RECORD.NMPRODUTO            := V_NMPRODUTO;
      OUT_RECORD.CDPRODUTO            := V_CDPRODUTO;
      OUT_RECORD.SGUNIDADE            := V_SGUNIDADE;
      OUT_RECORD.CDMARCA              := V_CDMARCA;
      OUT_RECORD.CDMARCAOL            := V_CDMARCAOL;
      OUT_RECORD.CDMARCAAF            := V_CDMARCAAF;
      OUT_RECORD.NMMARCA              := V_NMMARCA;
      OUT_RECORD.NRAUTOFORN           := V_NRAUTOFORN;
      OUT_RECORD.CDFILLANC            := V_CDFILLANC;
      OUT_RECORD.NRLANCTONF           := V_NRLANCTONF;
      OUT_RECORD.IDBAIXITAFS          := V_IDBAIXITAFS;
      OUT_RECORD.CDFILDEST            := V_CDFILDEST;
      OUT_RECORD.IDUTILITEM           := V_IDUTILITEM;
      OUT_RECORD.CDALMOXARIFE         := V_CDALMOXARIFE;
      OUT_RECORD.CDLOCALESTOQ         := V_CDLOCALESTOQ;
      OUT_RECORD.NRLOTEESTQ           := V_NRLOTEESTQ;
      OUT_RECORD.NRSUBLOTE            := V_NRSUBLOTE;
      OUT_RECORD.IDUTQTESTRANG        := V_IDUTQTESTRANG;
      OUT_RECORD.CDCLIENTEEXT         := V_CDCLIENTEEXT;
      OUT_RECORD.DTPROGEMBARQ         := V_DTPROGEMBARQ;
      OUT_RECORD.DTPROGENTAF          := V_DTPROGENTAF;
      OUT_RECORD.DTPROGENPEOL         := V_DTPROGENPEOL;
      OUT_RECORD.QTPROGENTAF          := V_QTPROGENTAF;
      OUT_RECORD.QTSAIDOPLOG          := V_QTSAIDOPLOG;
      OUT_RECORD.VRPREUNIAF           := V_VRPREUNIAF;
      OUT_RECORD.QTNFRELAFSAI         := V_QTNFRELAFSAI;
      OUT_RECORD.QTATENDPEDOL         := V_QTATENDPEDOL;
      OUT_RECORD.VRPBRUTOPEDOL        := V_VRPBRUTOPEDOL;
      OUT_RECORD.VRPLIQUIPEDOL        := V_VRPLIQUIPEDOL;
      OUT_RECORD.QTATENDESTRANG       := V_QTATENDESTRANG;
      PIPE ROW (OUT_RECORD);
   END LOOP;
   CLOSE C_ITEM;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('QUERY_ITEM_DFS48000','6.39.016'); END;
/
